@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "terraform-docs" "0.1"
-  "Integrate terraform-docs."
+(define-package "terraform-docs" "20241216.649"
+  "Generate Terraform modules documentation with terraform-docs."
   '((emacs "27.1"))
   :url "https://github.com/loispostula/terraform-docs.el"
-  :commit "94a78999ec03e66ce49f7343cc8705354e195c3a"
-  :revdesc "94a78999ec03"
+  :commit "c70d19c4007d81244b276b9d150cdfe3c2e7b8dd"
+  :revdesc "c70d19c4007d"
   :keywords '("terraform" "tools" "docs")
   :authors '(("Lois Postula" . "lois@postu.la"))
   :maintainers '(("Lois Postula" . "lois@postu.la")))
